@@ -90,6 +90,8 @@ static gboolean     convert_pre_v3_parameters( NAObjectProfile *profile );
 static gboolean     convert_pre_v3_parameters_str( gchar *str );
 static gboolean     convert_pre_v3_multiple( NAObjectProfile *profile );
 static gboolean     convert_pre_v3_isfiledir( NAObjectProfile *profile );
+static void         read_done_ending( NAObjectProfile *profile );
+static void         split_path_parameters( NAObjectProfile *profile );
 static gboolean     profile_is_valid( const NAObjectProfile *profile );
 static gboolean     is_valid_path_parameters( const NAObjectProfile *profile );
 
@@ -345,22 +347,10 @@ ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider
 	g_debug( "%s: iversion=%d", thisfn, iversion );
 
 	if( iversion < 3 ){
-
-		if( convert_pre_v3_parameters( NA_OBJECT_PROFILE( instance )) ||
-			convert_pre_v3_multiple( NA_OBJECT_PROFILE( instance )) ||
-			convert_pre_v3_isfiledir( NA_OBJECT_PROFILE( instance ))){
-
-				na_object_set_iversion( action, 3 );
-		}
+		na_object_profile_convert_v2_to_last( NA_OBJECT_PROFILE( instance ));
 	}
 
-	/* prepare the context after the reading
-	 */
-	na_icontext_read_done( NA_ICONTEXT( instance ));
-
-	/* last, set other action defaults
-	 */
-	na_factory_object_set_defaults( instance );
+	read_done_ending( NA_OBJECT_PROFILE( instance ));
 }
 
 static guint
@@ -397,8 +387,8 @@ icontext_is_candidate( NAIContext *object, guint target, GList *selection )
  *   %f: (first) filename	-> %b		%f: (first) pathname	(new)
  *   									%F: list of pathnames	(was %M)
  *   %h: (first) hostname				...................		(unchanged)
- *   %m: list of basenames	-> %B		-						(removed)
- *   %M: list of pathnames	-> %F		-						(removed)
+ *   %m: list of basenames	-> %B		%m: (first) mimetype	(new)
+ *   %M: list of pathnames	-> %F		%M: list of mimetypes	(new)
  *   									%n: (first) username	(was %U)
  *   %p: (first) port number			...................		(unchanged)
  *   %R: list of URIs		-> %U		-						(removed)
@@ -412,11 +402,11 @@ icontext_is_candidate( NAIContext *object, guint target, GList *selection )
  *   %%: %								...................		(unchanged)
  *
  * For pre-v3 items,
- * - substitute %f with %b
+ * - substitute %f with %b, and as a special case %d/%f -> %f
  * - substitute %m with %B
  * - substitute %M with %F
- * - substitute %U with %n
  * - substitute %R with %U
+ * - substitute %U with %n
  *
  * Note that pre-v3 items only have parameters in the command and path fields.
  * Are only located in 'profile' objects.
@@ -457,6 +447,7 @@ convert_pre_v3_parameters( NAObjectProfile *profile )
 static gboolean
 convert_pre_v3_parameters_str( gchar *str )
 {
+	static const gchar *thisfn = "na_object_profile_convert_pre_v3_parameters_str";
 	gboolean changed;
 	gchar *iter = str;
 
@@ -465,9 +456,19 @@ convert_pre_v3_parameters_str( gchar *str )
 			strlen( iter ) > 0 &&
 			( iter = g_strstr_len( iter, strlen( iter ), "%" )) != NULL ){
 
-		g_debug( "convert_pre_v3_parameters_str: iter[1]='%c'", iter[1] );
+		g_debug( "%s: iter[1]='%c'", thisfn, iter[1] );
 		switch( iter[1] ){
 
+			/* as a special optimization case, "%d/%f" parameters
+			 * may be favourably converted to just "%f" instead of "%d/%b"
+			 */
+			case 'd':
+				if( !strncmp( iter, "%d/%f", 5 )){
+					strncpy( iter, iter+3, strlen( iter ));
+					changed = TRUE;
+				}
+				break;
+
 			/* %f (first filename) becomes %b
 			 */
 			case 'f':
@@ -489,19 +490,19 @@ convert_pre_v3_parameters_str( gchar *str )
 				changed = TRUE;
 				break;
 
-			/* %U ((first) username) becomes %n
-			 */
-			case 'U':
-				iter[1] = 'n';
-				changed = TRUE;
-				break;
-
 			/* %R (list of URIs) becomes %U
 			 */
 			case 'R':
 				iter[1] = 'U';
 				changed = TRUE;
 				break;
+
+			/* %U ((first) username) becomes %n
+			 */
+			case 'U':
+				iter[1] = 'n';
+				changed = TRUE;
+				break;
 		}
 
 		iter += 2;
@@ -523,6 +524,7 @@ convert_pre_v3_multiple( NAObjectProfile *profile )
 	accept_multiple = na_object_is_multiple( profile );
 	selection_count = g_strdup( accept_multiple ? ">0" : "=1" );
 	na_object_set_selection_count( profile, selection_count );
+	g_debug( "na_object_profile_convert_pre_v3_multiple: set selection_count=%s", selection_count );
 	g_free( selection_count );
 
 	return( TRUE );
@@ -585,6 +587,44 @@ convert_pre_v3_isfiledir( NAObjectProfile *profile )
 	return( converted );
 }
 
+static void
+read_done_ending( NAObjectProfile *profile )
+{
+	/* split path+parameters
+	 * not done in io-desktop because some actions may have all arguments in path
+	 */
+	split_path_parameters( profile );
+
+	/* prepare the context after the reading
+	 */
+	na_icontext_read_done( NA_ICONTEXT( profile ));
+
+	/* last, set other action defaults
+	 */
+	na_factory_object_set_defaults( NA_IFACTORY_OBJECT( profile ));
+}
+
+static void
+split_path_parameters( NAObjectProfile *profile )
+{
+	gchar *path, *parameters;
+	gchar *exec;
+
+	path = na_object_get_path( profile );
+	parameters = na_object_get_parameters( profile );
+	exec = g_strstrip( g_strdup_printf( "%s %s", path ? path : "", parameters ? parameters : "" ));
+	g_free( parameters );
+	g_free( path );
+
+	na_core_utils_str_split_first_word( exec, &path, &parameters );
+	g_free( exec );
+
+	na_object_set_path( profile, path );
+	na_object_set_parameters( profile, parameters );
+	g_free( parameters );
+	g_free( path );
+}
+
 static gboolean
 profile_is_valid( const NAObjectProfile *profile )
 {
@@ -691,3 +731,32 @@ na_object_profile_new_with_defaults( void )
 
 	return( profile );
 }
+
+/**
+ * na_object_profile_convert_v2_to_last:
+ *
+ * Converts to v3 a @profile which has just been created from a pre-v2 action.
+ */
+void
+na_object_profile_convert_v2_to_last( NAObjectProfile *profile )
+{
+	NAObjectAction *action;
+	guint iversion;
+	gboolean parms_converted, multiple_converted, isfiledir_converted;
+
+	g_return_if_fail( NA_IS_OBJECT_PROFILE( profile ));
+
+	action = NA_OBJECT_ACTION( na_object_get_parent( profile ));
+	iversion = na_object_get_iversion( action );
+	g_return_if_fail( iversion < 3 );
+
+	parms_converted = convert_pre_v3_parameters( profile );
+	multiple_converted = convert_pre_v3_multiple( profile );
+	isfiledir_converted = convert_pre_v3_isfiledir( profile );
+
+	if( parms_converted || multiple_converted || isfiledir_converted ){
+		na_object_set_iversion( action, 3 );
+	}
+
+	read_done_ending( profile );
+}
