@@ -59,6 +59,7 @@
 #include "nact-iproperties-tab.h"
 #include "nact-main-tab.h"
 #include "nact-main-menubar.h"
+#include "nact-main-menubar-file.h"
 #include "nact-main-statusbar.h"
 #include "nact-marshal.h"
 #include "nact-main-window.h"
@@ -173,18 +174,22 @@ static void     on_main_window_level_zero_order_changed( NactMainWindow *window,
 static void     on_iactions_list_selection_changed( NactIActionsList *instance, GSList *selected_items );
 static void     on_iactions_list_status_changed( NactMainWindow *window, gpointer user_data );
 static void     raz_main_properties( NactMainWindow *window );
-static void     set_current_object_item( NactMainWindow *window, GSList *selected_items );
-static void     set_current_profile( NactMainWindow *window, gboolean set_action, GSList *selected_items );
-static gchar   *iactions_list_get_treeview_name( NactIActionsList *instance );
+static void     setup_current_selection( NactMainWindow *window, NAObjectId *selected_row );
 static void     setup_dialog_title( NactMainWindow *window );
+static void     setup_writability_status( NactMainWindow *window );
+static gchar   *iactions_list_get_treeview_name( NactIActionsList *instance );
 
 static void     on_tab_updatable_item_updated( NactMainWindow *window, gpointer user_data, gboolean force_display );
 
 static gboolean confirm_for_giveup_from_menu( NactMainWindow *window );
 static gboolean confirm_for_giveup_from_pivot( NactMainWindow *window );
+static void     install_autosave( NactMainWindow *window );
+static void     ipivot_consumer_on_autosave_changed( NAIPivotConsumer *instance, gboolean enabled, guint period );
 static void     ipivot_consumer_on_items_changed( NAIPivotConsumer *instance, gpointer user_data );
 static void     ipivot_consumer_on_display_order_changed( NAIPivotConsumer *instance, gint order_mode );
+static void     ipivot_consumer_on_io_provider_prefs_changed( NAIPivotConsumer *instance );
 static void     ipivot_consumer_on_mandatory_prefs_changed( NAIPivotConsumer *instance );
+static void     update_ui_after_provider_change( NactMainWindow *window );
 static void     reload( NactMainWindow *window );
 
 static gchar   *iabout_get_application_name( NAIAbout *instance );
@@ -605,10 +610,12 @@ ipivot_consumer_iface_init( NAIPivotConsumerInterface *iface )
 
 	g_debug( "%s: iface=%p", thisfn, ( void * ) iface );
 
-	iface->on_items_changed = ipivot_consumer_on_items_changed;
+	iface->on_autosave_changed = ipivot_consumer_on_autosave_changed;
 	iface->on_create_root_menu_changed = NULL;
 	iface->on_display_about_changed = NULL;
 	iface->on_display_order_changed = ipivot_consumer_on_display_order_changed;
+	iface->on_io_provider_prefs_changed = ipivot_consumer_on_io_provider_prefs_changed;
+	iface->on_items_changed = ipivot_consumer_on_items_changed;
 	iface->on_mandatory_prefs_changed = ipivot_consumer_on_mandatory_prefs_changed;
 }
 
@@ -658,6 +665,8 @@ instance_init( GTypeInstance *instance, gpointer klass )
 			G_CALLBACK( on_tab_updatable_item_updated ));
 
 	self->private->dispose_has_run = FALSE;
+
+	na_ipivot_consumer_allow_notify( NA_IPIVOT_CONSUMER( instance ), TRUE, 0 );
 }
 
 static void
@@ -1201,6 +1210,8 @@ on_base_all_widgets_showed( NactMainWindow *window, gpointer user_data )
 
 		nact_iactions_list_all_widgets_showed( NACT_IACTIONS_LIST( window ));
 		nact_sort_buttons_all_widgets_showed( window );
+
+		install_autosave( window );
 	}
 }
 
@@ -1222,10 +1233,7 @@ on_iactions_list_selection_changed( NactIActionsList *instance, GSList *selected
 {
 	static const gchar *thisfn = "nact_main_window_on_iactions_list_selection_changed";
 	NactMainWindow *window;
-	NAObject *object;
 	gint count;
-	NactApplication *application;
-	NAUpdater *updater;
 
 	count = g_slist_length( selected_items );
 
@@ -1242,32 +1250,22 @@ on_iactions_list_selection_changed( NactIActionsList *instance, GSList *selected
 
 	if( count == 1 ){
 		g_return_if_fail( NA_IS_OBJECT_ID( selected_items->data ));
-		object = NA_OBJECT( selected_items->data );
-
-		if( NA_IS_OBJECT_ITEM( object )){
-			window->private->selected_item = NA_OBJECT_ITEM( object );
-			set_current_object_item( window, selected_items );
-
-		} else {
-			g_assert( NA_IS_OBJECT_PROFILE( object ));
-			window->private->selected_profile = NA_OBJECT_PROFILE( object );
-			set_current_profile( window, TRUE, selected_items );
-		}
-
-		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
-		updater = nact_application_get_updater( application );
-		window->private->editable = na_updater_is_item_writable( updater, window->private->selected_item, &window->private->reason );
-		nact_main_statusbar_set_locked( window, !window->private->editable, window->private->reason );
-
-	} else {
-		set_current_object_item( window, selected_items );
+		setup_current_selection( window, NA_OBJECT_ID( selected_items->data ));
+		setup_writability_status( window );
 	}
 
 	setup_dialog_title( window );
-
 	g_signal_emit_by_name( window, MAIN_WINDOW_SIGNAL_SELECTION_CHANGED, GINT_TO_POINTER( count ));
 }
 
+static void
+on_iactions_list_status_changed( NactMainWindow *window, gpointer user_data )
+{
+	g_debug( "nact_main_window_on_iactions_list_status_changed" );
+
+	setup_dialog_title( window );
+}
+
 static void
 raz_main_properties( NactMainWindow *window )
 {
@@ -1279,79 +1277,33 @@ raz_main_properties( NactMainWindow *window )
 	nact_main_statusbar_set_locked( window, FALSE, 0 );
 }
 
-static void
-on_iactions_list_status_changed( NactMainWindow *window, gpointer user_data )
-{
-	g_debug( "nact_main_window_on_iactions_list_status_changed" );
-
-	setup_dialog_title( window );
-}
-
 /*
- * update the notebook when selection changes in ActionsList
- * if there is only one profile, we also setup the profile
- * count_profiles may be null (invalid action)
+ * enter after raz_properties
+ * only called when only one selected row
  */
 static void
-set_current_object_item( NactMainWindow *window, GSList *selected_items )
+setup_current_selection( NactMainWindow *window, NAObjectId *selected_row )
 {
-	static const gchar *thisfn = "nact_main_window_set_current_object_item";
-	gint count_profiles;
+	guint nb_profiles;
 	GList *profiles;
-	/*NAObject *current;*/
 
-	g_debug( "%s: window=%p, current=%p, selected_items=%p",
-			thisfn, ( void * ) window, ( void * ) window->private->selected_item, ( void * ) selected_items );
+	if( NA_IS_OBJECT_PROFILE( selected_row )){
+		window->private->selected_profile = NA_OBJECT_PROFILE( selected_row );
+		window->private->selected_item = NA_OBJECT_ITEM( na_object_get_parent( selected_row ));
 
-	/* set the profile to be displayed, if any
-	 */
-	window->private->selected_profile = NULL;
+	} else {
+		g_return_if_fail( NA_IS_OBJECT_ITEM( selected_row ));
+		window->private->selected_item = NA_OBJECT_ITEM( selected_row );
 
-	if( window->private->selected_item ){
+		if( NA_IS_OBJECT_ACTION( selected_row )){
+			nb_profiles = na_object_get_items_count( selected_row );
 
-		if( NA_IS_OBJECT_ACTION( window->private->selected_item )){
-
-			count_profiles = na_object_get_items_count( window->private->selected_item );
-			/*g_return_if_fail( count_profiles >= 1 );*/
-
-			if( count_profiles == 1 ){
-				profiles = na_object_get_items( window->private->selected_item );
+			if( nb_profiles == 1 ){
+				profiles = na_object_get_items( selected_row );
 				window->private->selected_profile = NA_OBJECT_PROFILE( profiles->data );
 			}
 		}
 	}
-
-	set_current_profile( window, FALSE, selected_items );
-}
-
-static void
-set_current_profile( NactMainWindow *window, gboolean set_action, GSList *selected_items )
-{
-	static const gchar *thisfn = "nact_main_window_set_current_profile";
-
-	g_debug( "%s: window=%p, set_action=%s, selected_items=%p",
-			thisfn, ( void * ) window, set_action ? "True":"False", ( void * ) selected_items );
-
-	if( window->private->selected_profile && set_action ){
-
-		NAObjectAction *action = NA_OBJECT_ACTION( na_object_get_parent( window->private->selected_profile ));
-		NactApplication *application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-		NAUpdater *updater = nact_application_get_updater( application );
-		window->private->selected_item = NA_OBJECT_ITEM( action );
-		window->private->editable = na_updater_is_item_writable( updater, window->private->selected_item, &window->private->reason );
-	}
-}
-
-static gchar *
-iactions_list_get_treeview_name( NactIActionsList *instance )
-{
-	gchar *name = NULL;
-
-	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( instance ), NULL );
-
-	name = g_strdup( "ActionsList" );
-
-	return( name );
 }
 
 /*
@@ -1394,6 +1346,32 @@ setup_dialog_title( NactMainWindow *window )
 	g_free( title );
 }
 
+static void
+setup_writability_status( NactMainWindow *window )
+{
+	NactApplication *application;
+	NAUpdater *updater;
+
+	g_return_if_fail( NA_IS_OBJECT_ITEM( window->private->selected_item ));
+
+	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+	updater = nact_application_get_updater( application );
+	window->private->editable = na_updater_is_item_writable( updater, window->private->selected_item, &window->private->reason );
+	nact_main_statusbar_set_locked( window, !window->private->editable, window->private->reason );
+}
+
+static gchar *
+iactions_list_get_treeview_name( NactIActionsList *instance )
+{
+	gchar *name = NULL;
+
+	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( instance ), NULL );
+
+	name = g_strdup( "ActionsList" );
+
+	return( name );
+}
+
 static void
 on_tab_updatable_item_updated( NactMainWindow *window, gpointer user_data, gboolean force_display )
 {
@@ -1468,6 +1446,22 @@ confirm_for_giveup_from_pivot( NactMainWindow *window )
 	return( reload_ok );
 }
 
+static void
+install_autosave( NactMainWindow *window )
+{
+	gboolean autosave_on;
+	guint autosave_period;
+	NactApplication *application;
+	NAUpdater *updater;
+
+	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+	updater = nact_application_get_updater( application );
+	autosave_on = na_iprefs_read_bool( NA_IPREFS( updater ), IPREFS_AUTOSAVE_ON, FALSE );
+	autosave_period = na_iprefs_read_uint( NA_IPREFS( updater ), IPREFS_AUTOSAVE_PERIOD, 5 );
+
+	nact_main_menubar_file_set_autosave( window, autosave_on, autosave_period );
+}
+
 /*
  * called by NAPivot because this window implements the IIOConsumer
  * interface, i.e. it wish to be advertised when the list of actions
@@ -1498,30 +1492,20 @@ ipivot_consumer_on_items_changed( NAIPivotConsumer *instance, gpointer user_data
 	}
 }
 
+/*
+ * called by NAPivot via NAIPivotConsumer whenever the
+ * autosave preferences have been modified.
+ */
 static void
-reload( NactMainWindow *window )
+ipivot_consumer_on_autosave_changed( NAIPivotConsumer *instance, gboolean enabled, guint period )
 {
-	static const gchar *thisfn = "nact_main_window_reload";
-	NactApplication *application;
-	NAUpdater *updater;
+	static const gchar *thisfn = "nact_main_window_ipivot_consumer_on_autosave_changed";
 
-	g_debug( "%s: window=%p", thisfn, ( void * ) window );
-	g_return_if_fail( NACT_IS_MAIN_WINDOW( window ));
+	g_return_if_fail( NACT_IS_MAIN_WINDOW( instance ));
+	g_debug( "%s: instance=%p, enabled=%s, period=%d",
+			thisfn, ( void * ) instance, enabled ? "True":"False", period );
 
-	if( !window->private->dispose_has_run ){
-
-		window->private->selected_item = NULL;
-		window->private->selected_profile = NULL;
-
-		na_object_unref_items( window->private->deleted );
-		window->private->deleted = NULL;
-
-		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-		updater = nact_application_get_updater( application );
-		na_pivot_load_items( NA_PIVOT( updater ));
-		nact_iactions_list_fill( NACT_IACTIONS_LIST( window ), na_pivot_get_items( NA_PIVOT( updater )));
-		nact_iactions_list_bis_select_first_row( NACT_IACTIONS_LIST( window ));
-	}
+	nact_main_menubar_file_set_autosave( NACT_MAIN_WINDOW( instance ), enabled, period );
 }
 
 /*
@@ -1554,10 +1538,53 @@ ipivot_consumer_on_display_order_changed( NAIPivotConsumer *instance, gint order
 	}
 }
 
+static void
+ipivot_consumer_on_io_provider_prefs_changed( NAIPivotConsumer *instance )
+{
+	update_ui_after_provider_change( NACT_MAIN_WINDOW( instance ));
+}
+
 static void
 ipivot_consumer_on_mandatory_prefs_changed( NAIPivotConsumer *instance )
 {
-	nact_sort_buttons_level_zero_writability_change( NACT_MAIN_WINDOW( instance ));
+	update_ui_after_provider_change( NACT_MAIN_WINDOW( instance ));
+}
+
+static void
+update_ui_after_provider_change( NactMainWindow *window )
+{
+	nact_sort_buttons_level_zero_writability_change( window );
+
+	if( window->private->selected_item ){
+		setup_writability_status( window );
+		g_signal_emit_by_name( window, MAIN_WINDOW_SIGNAL_SELECTION_CHANGED, GINT_TO_POINTER( 1 ));
+	}
+}
+
+static void
+reload( NactMainWindow *window )
+{
+	static const gchar *thisfn = "nact_main_window_reload";
+	NactApplication *application;
+	NAUpdater *updater;
+
+	g_debug( "%s: window=%p", thisfn, ( void * ) window );
+	g_return_if_fail( NACT_IS_MAIN_WINDOW( window ));
+
+	if( !window->private->dispose_has_run ){
+
+		window->private->selected_item = NULL;
+		window->private->selected_profile = NULL;
+
+		na_object_unref_items( window->private->deleted );
+		window->private->deleted = NULL;
+
+		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+		updater = nact_application_get_updater( application );
+		na_pivot_load_items( NA_PIVOT( updater ));
+		nact_iactions_list_fill( NACT_IACTIONS_LIST( window ), na_pivot_get_items( NA_PIVOT( updater )));
+		nact_iactions_list_bis_select_first_row( NACT_IACTIONS_LIST( window ));
+	}
 }
 
 static gchar *
